@@ -16,10 +16,23 @@
         renderNoHealthAlertsMessage(page);
     }
 
+    function onConnectionHelpClick(e) {
+
+        e.preventDefault();
+        return false;
+    }
+
     window.DashboardPage = {
 
         newsStartIndex: 0,
 
+        onPageInit: function () {
+
+            var page = this;
+
+            page.querySelector('.btnConnectionHelp').addEventListener('click', onConnectionHelpClick);
+        },
+
         onPageShow: function () {
 
             var page = this;
@@ -30,10 +43,6 @@
                 return;
             }
 
-            if (Dashboard.lastSystemInfo) {
-                page.querySelector('.serverNameHeader').innerHTML = Dashboard.lastSystemInfo.ServerName;
-            }
-
             DashboardPage.newsStartIndex = 0;
 
             Dashboard.showLoadingMsg();
@@ -105,9 +114,13 @@
             ApiClient.getSystemInfo().then(function (systemInfo) {
 
                 page.querySelector('.serverNameHeader').innerHTML = systemInfo.ServerName;
-                Dashboard.updateSystemInfo(systemInfo);
 
-                $('#appVersionNumber', page).html(Globalize.translate('LabelVersionNumber').replace('{0}', systemInfo.Version));
+                var localizedVersion = Globalize.translate('LabelVersionNumber', systemInfo.Version);
+                if (systemInfo.SystemUpdateLevel && systemInfo.SystemUpdateLevel != 'Release') {
+                    localizedVersion += " " + Globalize.translate('Option' + systemInfo.SystemUpdateLevel).toLowerCase();
+                }
+
+                $('#appVersionNumber', page).html(localizedVersion);
 
                 if (systemInfo.SupportsHttps) {
                     $('#ports', page).html(Globalize.translate('LabelRunningOnPorts', '<b>' + systemInfo.HttpServerPortNumber + '</b>', '<b>' + systemInfo.HttpsPortNumber + '</b>'));
@@ -151,28 +164,28 @@
                     var itemHtml = '';
 
                     itemHtml += '<a class="clearLink" href="' + item.Link + '" target="_blank">';
-                    itemHtml += '<paper-icon-item>';
+                    itemHtml += '<div class="listItem listItem-noborder">';
 
-                    itemHtml += '<paper-fab mini class="blue" icon="dvr" item-icon></paper-fab>';
+                    itemHtml += '<i class="listItemIcon md-icon">dvr</i>';
 
-                    itemHtml += '<paper-item-body three-line>';
+                    itemHtml += '<div class="listItemBody three-line">';
 
-                    itemHtml += '<div>';
+                    itemHtml += '<h3 class="listItemBodyText">';
                     itemHtml += item.Title;
-                    itemHtml += '</div>';
+                    itemHtml += '</h3>';
 
-                    itemHtml += '<div secondary>';
+                    itemHtml += '<div class="listItemBodyText secondary">';
                     var date = datetime.parseISO8601Date(item.Date, true);
                     itemHtml += date.toLocaleDateString();
                     itemHtml += '</div>';
 
-                    itemHtml += '<div secondary>';
+                    itemHtml += '<div class="listItemBodyText secondary listItemBodyText-nowrap">';
                     itemHtml += item.Description;
                     itemHtml += '</div>';
 
-                    itemHtml += '</paper-item-body>';
+                    itemHtml += '</div>';
 
-                    itemHtml += '</paper-icon-item>';
+                    itemHtml += '</div>';
                     itemHtml += '</a>';
 
                     return itemHtml;
@@ -309,7 +322,7 @@
 
                 var nowPlayingItem = session.NowPlayingItem;
 
-                var className = nowPlayingItem ? 'scalableCard card activeSession' : 'scalableCard card activeSession';
+                var className = nowPlayingItem ? 'scalableCard card activeSession backdropCard backdropCard-scalable' : 'scalableCard card activeSession backdropCard backdropCard-scalable';
 
                 if (session.TranscodingInfo && session.TranscodingInfo.CompletionPercentage) {
                     className += ' transcodingSession';
@@ -318,9 +331,9 @@
                 html += '<div class="' + className + '" id="' + rowId + '">';
 
                 html += '<div class="cardBox visualCardBox">';
-                html += '<div class="cardScalable">';
+                html += '<div class="cardScalable visualCardBox-cardScalable">';
 
-                html += '<div class="cardPadder"></div>';
+                html += '<div class="cardPadder cardPadder-backdrop"></div>';
                 html += '<div class="cardContent">';
 
                 html += '<div class="sessionNowPlayingContent"';
@@ -427,6 +440,7 @@
 
             //html += '<div>';
             var showTranscodingInfo = false;
+
             if (session.TranscodingInfo && session.TranscodingInfo.IsAudioDirect && session.TranscodingInfo.IsVideoDirect) {
                 html += Globalize.translate('LabelPlayMethodDirectStream');
             }
@@ -455,28 +469,30 @@
 
                 var line = [];
 
-                if (session.TranscodingInfo.Bitrate) {
+                if (session.TranscodingInfo) {
+                    if (session.TranscodingInfo.Bitrate) {
 
-                    if (session.TranscodingInfo.Bitrate > 1000000) {
-                        line.push((session.TranscodingInfo.Bitrate / 1000000).toFixed(1) + ' Mbps');
-                    } else {
-                        line.push(Math.floor(session.TranscodingInfo.Bitrate / 1000) + ' kbps');
+                        if (session.TranscodingInfo.Bitrate > 1000000) {
+                            line.push((session.TranscodingInfo.Bitrate / 1000000).toFixed(1) + ' Mbps');
+                        } else {
+                            line.push(Math.floor(session.TranscodingInfo.Bitrate / 1000) + ' kbps');
+                        }
                     }
-                }
-                if (session.TranscodingInfo.Container) {
+                    if (session.TranscodingInfo.Container) {
 
-                    line.push(session.TranscodingInfo.Container);
-                }
+                        line.push(session.TranscodingInfo.Container);
+                    }
 
-                if (session.TranscodingInfo.VideoCodec) {
+                    if (session.TranscodingInfo.VideoCodec) {
 
-                    //line.push(Globalize.translate('LabelVideoCodec').replace('{0}', session.TranscodingInfo.VideoCodec));
-                    line.push(session.TranscodingInfo.VideoCodec);
-                }
-                if (session.TranscodingInfo.AudioCodec && session.TranscodingInfo.AudioCodec != session.TranscodingInfo.Container) {
+                        //line.push(Globalize.translate('LabelVideoCodec').replace('{0}', session.TranscodingInfo.VideoCodec));
+                        line.push(session.TranscodingInfo.VideoCodec);
+                    }
+                    if (session.TranscodingInfo.AudioCodec && session.TranscodingInfo.AudioCodec != session.TranscodingInfo.Container) {
 
-                    //line.push(Globalize.translate('LabelAudioCodec').replace('{0}', session.TranscodingInfo.AudioCodec));
-                    line.push(session.TranscodingInfo.AudioCodec);
+                        //line.push(Globalize.translate('LabelAudioCodec').replace('{0}', session.TranscodingInfo.AudioCodec));
+                        line.push(session.TranscodingInfo.AudioCodec);
+                    }
                 }
 
                 if (line.length) {
@@ -1023,7 +1039,7 @@
         }
     };
 
-    $(document).on('pageshow', "#dashboardPage", DashboardPage.onPageShow).on('pagebeforehide', "#dashboardPage", DashboardPage.onPageHide);
+    $(document).on('pageinit', "#dashboardPage", DashboardPage.onPageInit).on('pageshow', "#dashboardPage", DashboardPage.onPageShow).on('pagebeforehide', "#dashboardPage", DashboardPage.onPageHide);
 
     (function ($, document, window) {
 
@@ -1031,7 +1047,7 @@
 
             var html = '';
 
-            html += '<paper-icon-item>';
+            html += '<div class="listItem listItem-noborder">';
 
             var color = entry.Severity == 'Error' || entry.Severity == 'Fatal' || entry.Severity == 'Warn' ? '#cc0000' : '#52B54B';
 
@@ -1043,30 +1059,30 @@
                     height: 40
                 });
 
-                html += '<paper-fab mini style="background-color:' + color + ';background-image:url(\'' + userImgUrl + '\');background-repeat:no-repeat;background-position:center center;background-size: cover;" item-icon></paper-fab>';
+                html += '<i class="listItemIcon md-icon" style="width:2em!important;height:2em!important;padding:0;color:transparent;background-color:' + color + ';background-image:url(\'' + userImgUrl + '\');background-repeat:no-repeat;background-position:center center;background-size: cover;">dvr</i>';
             }
             else {
-                html += '<paper-fab mini icon="dvr" style="background-color:' + color + '" item-icon></paper-fab>';
+                html += '<i class="listItemIcon md-icon" style="background-color:' + color + '">dvr</i>';
             }
 
-            html += '<paper-item-body three-line>';
+            html += '<div class="listItemBody three-line">';
 
-            html += '<div>';
+            html += '<h3 class="listItemBodyText">';
             html += entry.Name;
-            html += '</div>';
+            html += '</h3>';
 
-            html += '<div secondary>';
+            html += '<div class="listItemBodyText secondary">';
             var date = datetime.parseISO8601Date(entry.Date, true);
             html += date.toLocaleDateString() + ' ' + date.toLocaleTimeString().toLowerCase();
             html += '</div>';
 
-            html += '<div secondary>';
+            html += '<div class="listItemBodyText secondary listItemBodyText-nowrap">';
             html += entry.ShortOverview || '';
             html += '</div>';
 
-            html += '</paper-item-body>';
+            html += '</div>';
 
-            html += '</paper-icon-item>';
+            html += '</div>';
 
             return html;
         }
